@@ -1,10 +1,9 @@
 import numpy as np
 from vipy.geometry import BoundingBox
-from vipy.util import isstring, tolist, chunklistwithoverlap
+from vipy.util import isstring, tolist, chunklistwithoverlap, try_import
 import uuid
 import copy
 import warnings
-import scipy.interpolate
 
 
 class Detection(BoundingBox):
@@ -145,7 +144,7 @@ class Track(object):
         strlist = []
         if self.category() is not None:
             strlist.append('category="%s"' % self.category())
-        if self.endframe() - self.startframe() > 0:
+        if self.endframe() is not None and self.startframe() is not None and ((self.endframe() - self.startframe()) > 0):
             strlist.append('startframe=%d, endframe=%d' % (self.startframe(), self.endframe()))
         strlist.append('keyframes=%d' % len(self._keyframes))
         return str('<vipy.object.track: %s>' % (', '.join(strlist)))
@@ -208,7 +207,7 @@ class Track(object):
         del self._keyboxes[k]
         del self._keyframes[k]
         if len(self._keyframes) == 0:
-            warnings.warn('Empty track')
+            warnings.warn('[vipy.object.Track]: Attempting to delete keyframe %d from empty track "%s" - Ignoring' % (keyframe, str(self)))
         return self
     
     def keyframes(self):
@@ -438,7 +437,11 @@ class Track(object):
         return self
 
     def spline(self, smoothingfactor=None):
-        """Track smoothing by cubic spline fit, will return resampled dt=1 track.  Smoothing factor will increase with smoothing > 1 and decrease with 0 < smoothing < 1"""
+        """Track smoothing by cubic spline fit, will return resampled dt=1 track.  Smoothing factor will increase with smoothing > 1 and decrease with 0 < smoothing < 1
+        
+           This function requires optional package scipy
+        """
+        try_import('scipy', 'scipy');  import scipy.interpolate;
         assert smoothingfactor is None or smoothingfactor > 0
         t = self.clone().resample(dt=1)
         s = smoothingfactor * len(self._keyframes) if smoothingfactor is not None else None
